@@ -9,11 +9,17 @@ from .. import __version__
 from .basecommand import BaseCommand
 
 from .apicommand import ApiCommand
+from .emailcommand import EmailCommand
+from .emailprocessorcommand import EmailProcessorCommand
 
+from .helpcommand import HelpCommand
 from .listcommand import ListCommand
 from .showcommand import ShowCommand
 from .testcommand import TestCommand
 from .closecommand import CloseCommand
 from .opencommand import OpenCommand
 from .configcommand import ConfigCommand
-from .mtacommand import MTACommand
+from .stdoutcommand import StdoutCommand
+from .mdacommand import MdaCommand
+from .smtpcommand import SmtpCommand
+from .versioncommand import VersionCommand
