@@ -2,21 +2,18 @@
 # Apache License Version 2.0 (See LICENSE.txt)
 # SPDX-License-Identifier: Apache-2.0
 
-from . import ApiCommand
-from .utils import register_command_class
-from hallo_eltern_cli import MessageToEmailConverter
+from . import EmailCommand
 
 
-class ShowCommand(ApiCommand):
-    def __init__(self, args, config):
-        super(ShowCommand, self).__init__(args, config)
-        self._message_converter = MessageToEmailConverter(
-            self._config, self._api.get_authenticated_user())
+class ShowCommand(EmailCommand):
+    @classmethod
+    def get_help(cls):
+        return 'shows a message'
 
     @classmethod
-    def register_subparser(cls, subparsers):
-        parser = register_command_class(
-            cls, subparsers, 'shows a message')
+    def register_options(cls, parser):
+        super(ShowCommand, cls).register_options(parser)
+
         parser.add_argument('id', help='The id of the message to show')
 
     def print_header(self, email, header):
