@@ -3,14 +3,12 @@
 # SPDX-License-Identifier: Apache-2.0
 
 from . import ApiCommand
-from .utils import register_command_class
 
 
 class TestCommand(ApiCommand):
     @classmethod
-    def register_subparser(cls, subparsers):
-        register_command_class(
-            cls, subparsers, 'tests the configured user againts the API')
+    def get_help(cls):
+        return 'tests the configured user againts the API'
 
     def run(self):
         response = self._api.authenticate()
