@@ -22,6 +22,7 @@ user-agent=hallo-eltern-cli/{{VERSION}}
 
 [email]
 default-address=do-not-reply@example.org
+forced-address=
 confirmation-needed-subject-prefix=[Confirmation needed]{{SPACE}}
 confirmed-subject-prefix=[Confirmed]{{SPACE}}
 
@@ -31,6 +32,10 @@ seen-ids-file={{CONFIG_DIR}}/seen-ids.json
 [development]
 development-mode=False
 cache-dir={{CACHE_DIR}}/api-development
+
+[smtp]
+host = localhost
+port = 25
 """\
     .replace('{{CONFIG_DIR}}', CONFIG_DIR)\
     .replace('{{CACHE_DIR}}', CACHE_DIR)\
@@ -69,6 +74,9 @@ def get_argument_parser(description):
                         default=0,
                         action='count',
                         help='increase verbosity')
+    parser.add_argument('--version',
+                        action='store_true',
+                        help='print the version and exit')
     return parser
 
 
